{% extends "!page.html" %}
{% block body %}
    {% if current_version and latest_version and current_version != latest_version %}
        <p id="version-warning">
            {% if current_version.is_released %}
                You're reading documentation for an <b>older version</b> of {{ project }}
                ({{ current_version.name }}). To read documentation for the latest released version,
                see <a href="{{ vpathto(latest_version.name) }}">{{latest_version.name}}</a>.
            {% else %}
                You're reading documentation for a <b>development version</b> of {{ project }}
                ({{ current_version.name }}). To read documentation for the latest released version,
                see <a href="{{ vpathto(latest_version.name) }}">{{latest_version.name}}</a>.
            {% endif %}
        </p>
    {% endif %}
    {{ super() }}
{% endblock %}