# Configuration file for the Sphinx documentation builder.
#
# For the full list of built-in configuration values, see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

import tattl
import datetime

project = "tattl"
author = "thcrt"
copyright = f"{datetime.date.today().year}, thcrt"
version = tattl.__version__
release = tattl.__version__

needs_sphinx = "8.1"

extensions = [
    "sphinx.ext.autodoc",
    "sphinx.ext.intersphinx",
    "sphinx.ext.coverage",
    "sphinx.ext.doctest",
    "sphinx_paramlinks",
    "sphinx.ext.autodoc.typehints",
    "sphinx_multiversion",
]

highlight_language = "python3"

nitpicky = True

maximum_signature_line_length = 80

templates_path = ["_templates"]
exclude_patterns = []

html_theme = "furo"
html_theme_options = {
    "source_repository": "https://github.com/thcrt/tattl/",
    "source_branch": "main",
    "source_directory": "docs/",
    "footer_icons": [
        {
            "name": "GitHub",
            "url": "https://github.com/thcrt/tattl",
            "html": """
                <svg stroke="currentColor" fill="currentColor" stroke-width="0" viewBox="0 0 16 16">
                    <path fill-rule="evenodd" d="M8 0C3.58 0 0 3.58 0 8c0 3.54 2.29 6.53 5.47 7.59.4.07.55-.17.55-.38 0-.19-.01-.82-.01-1.49-2.01.37-2.53-.49-2.69-.94-.09-.23-.48-.94-.82-1.13-.28-.15-.68-.52-.01-.53.63-.01 1.08.58 1.23.82.72 1.21 1.87.87 2.33.66.07-.52.28-.87.51-1.07-1.78-.2-3.64-.89-3.64-3.95 0-.87.31-1.59.82-2.15-.08-.2-.36-1.02.08-2.12 0 0 .67-.21 2.2.82.64-.18 1.32-.27 2-.27.68 0 1.36.09 2 .27 1.53-1.04 2.2-.82 2.2-.82.44 1.1.16 1.92.08 2.12.51.56.82 1.27.82 2.15 0 3.07-1.87 3.75-3.65 3.95.29.25.54.73.54 1.48 0 1.07-.01 1.93-.01 2.2 0 .21.15.46.55.38A8.013 8.013 0 0 0 16 8c0-4.42-3.58-8-8-8z"></path>
                </svg>
            """,
            "class": "",
        },
    ],
}

html_title = f"{project} docs"
html_last_updated_fmt = "%b %d, %Y"

html_static_path = ["_static"]
html_css_files = ["css/versions.css"]
html_js_files = ["js/versions.js"]

smv_released_pattern = r"^refs/tags/.*$"

add_function_parentheses = False

intersphinx_mapping = {"python": ("https://docs.python.org/3", None)}

autodoc_class_signature = "separated"
paramlinks_hyperlink_param = "name"


def remove_module_docstring(app, what, name, obj, options, lines):
    if what == "module" and name == "tattl":
        del lines[:]


def setup(app):
    app.connect("autodoc-process-docstring", remove_module_docstring)
