/*
    Slightly tweaked code from https://github.com/pradyunsg/furo/pull/500 vendored here until it
    gets merged. This adds a functioning version selector to the sidebar.
*/

#furo-versions {
    font-size: var(--sidebar-item-font-size);
    margin-bottom: 4em;
}

#furo-versions .latest-version {
    font-weight: bold;
}

#furo-versions .current-version {
    font-weight: bold;
}

#furo-versions .caption {
    display: inline-block;
    color: var(--color-sidebar-caption-text);
    font-weight: bold;
    text-transform: uppercase;
    font-size: var(--sidebar-caption-font-size);
    padding-right: var(--sidebar-expander-width);
    margin-top: 0;
}

#furo-versions input[type="checkbox"] {
    display: none;
    position: absolute;
    box-sizing: border-box;
    padding: 0;
    overflow: visible;
}

#furo-versions input[type="checkbox"]:checked ~ ul {
    display: inline-block;
    line-height: var(--sidebar-item-line-height);
    margin-left: var(--sidebar-item-spacing-horizontal);
    padding: var(--sidebar-item-spacing-vertical) var(--sidebar-item-spacing-horizontal);
    text-decoration: none;
}

#furo-versions ul {
    display: none;
}

#furo-versions .versions-label {
    position: relative;
    float: right;
}

/* 
    Also style the old/dev version warning
*/

#version-warning {
    color: var(--color-content-foreground);
    background-color: var(--color-admonition-title-background--caution);

    line-height: 1.3;

    margin: 0;
    padding: 0.5rem 3rem;
    position: relative;
}

#version-warning::before {
    background-color: var(--color-admonition-title--caution);
    mask-image: var(--icon-info);
    mask-repeat: no-repeat;

    content: "";
    position: absolute;

    height: 1.3rem;
    left: 1rem;
    width: 1.3rem;
}

#version-warning a {
    font-weight: bolder;
}
